@@ -108,8 +108,10 @@ ephy_profile_utils_do_migration (const char *profile_directory, int test_to_run,
   /* If we're not trying to run a migration step in a test and there
      is nothing to migrate, don't spawn the migrator at all. */
   if (test_to_run == -1 &&
-      EPHY_PROFILE_MIGRATION_VERSION == ephy_profile_utils_get_migration_version ())
+      EPHY_PROFILE_MIGRATION_VERSION == ephy_profile_utils_get_migration_version ()) {
+    g_strfreev (envp);
     return TRUE;
+  }
 
   if (test_to_run != -1) {
     index = g_strdup_printf ("%d", test_to_run);
