@@ -438,7 +438,7 @@ ephy_location_controller_constructed (GObject *object)
 
 	history_service = EPHY_HISTORY_SERVICE (ephy_embed_shell_get_global_history_service (ephy_embed_shell_get_default ()));
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
-	model = ephy_completion_model_new (history_service, bookmarks);
+	model = ephy_completion_model_new (history_service, bookmarks, TRUE);
 	ephy_location_entry_set_completion (priv->location_entry,
 					    GTK_TREE_MODEL (model),
 					    EPHY_COMPLETION_TEXT_COL,
